@@ -82,8 +82,8 @@ class _CreateCategoricalEncodedVariables(DoFn):
         with open('load_equipment_mlb.pkl', 'rb') as f:
             equipment_mlb = pickle.load(f)
 
-        download_blob("load_transforms", "load_quantile_mlb.pkl", "load_quantile_mlb.pkll")
-        with open('load_equipment_mlb.pkl', 'rb') as f:
+        download_blob("load_transforms", "load_quantile_mlb.pkl", "load_quantile_mlb.pkl")
+        with open('load_quantile_mlb.pkl', 'rb') as f:
             quantile_mlb = pickle.load(f)
 
         download_blob("load_transforms", "load_state_lbe.pkl", "load_state_lbe.pkl")
@@ -227,14 +227,14 @@ class _CreateLoadQuantiles(DoFn):
             # Find global quantile values
             global_result = load_quantile_df.loc[
                 (load_quantile_df['pickup_state'] == "GLOBAL") &
-                (load_quantile_df["dropoff_state"] == "GLOBAL") &
-                (load_quantile_df["equipment_type"] == equipment)]
+                (load_quantile_df['dropoff_state'] == "GLOBAL") &
+                (load_quantile_df['equipment_type'] == equipment)]
 
             # Find state to state quantile values
             state_to_state_result = load_quantile_df.loc[
                 (load_quantile_df['pickup_state'] == pickup_state) &
-                (load_quantile_df["dropoff_state"] == dropoff_state) &
-                (load_quantile_df["equipment_type"] == equipment)]
+                (load_quantile_df['dropoff_state'] == dropoff_state) &
+                (load_quantile_df['equipment_type'] == equipment)]
 
             # If no State to State use Global
             if state_to_state_result.empty:
@@ -252,8 +252,9 @@ class _CreateLoadQuantiles(DoFn):
             distance_quantile.append(map_quantiles_for_entry("distance", state_to_state_result, row))
             distance_p50.append(get_p50_value("distance", global_result))
 
-        df["weight_quantile"] = weight_quantile
-        df["weight_p50"] = weight_p50
+        df['weight_quantile'] = weight_quantile
+        df['weight_p50'] = weight_p50
+        df['weight'] = pd.to_numeric(df['weight'], errors='coerce')
         df['weight'] = df.apply(
             lambda row: row['weight_p50']
             if (np.isnan(row['weight']) or row['weight'] in [0, 1.0])
@@ -261,8 +262,9 @@ class _CreateLoadQuantiles(DoFn):
             axis=1
         )
 
-        df["price_quantile"] = price_quantile
-        df["price_p50"] = price_p50
+        df['price_quantile'] = price_quantile
+        df['price_p50'] = price_p50
+        df['price'] = pd.to_numeric(df['price'], errors='coerce')
         df['price'] = df.apply(
             lambda row: row['price_p50']
             if (np.isnan(row['price']) or row['price'] in [0, 1.0])
@@ -270,16 +272,18 @@ class _CreateLoadQuantiles(DoFn):
             axis=1
         )
 
-        df["per_mile_rate_quantile"] = per_mile_quantile
-        df["per_mile_rate_p50"] = per_mile_p50
+        df['per_mile_rate_quantile'] = per_mile_quantile
+        df['per_mile_rate_p50'] = per_mile_p50
+        df['per_mile_rate'] = pd.to_numeric(df['per_mile_rate'], errors='coerce')
         df['per_mile_rate'] = df.apply(
             lambda row: row['per_mile_rate_p50']
             if (np.isnan(row['per_mile_rate']) or row['per_mile_rate'] == 0)
             else row['per_mile_rate'],
             axis=1
         )
-        df["distance_quantile"] = distance_quantile
-        df["distance_p50"] = distance_p50
+        df['distance_quantile'] = distance_quantile
+        df['distance_p50'] = distance_p50
+        df['distance'] = pd.to_numeric(df['distance'], errors='coerce')
         df['distance'] = df.apply(
             lambda row: row['distance_p50']
             if (np.isnan(row['distance']) or row['distance'] in [0, 1.0])
